@@ -1,4 +1,4 @@
-# Sebastian Raschka 2014-2017
+# Sebastian Raschka 2014-2018
 # mlxtend Machine Learning Library Extensions
 # Author: Sebastian Raschka <sebastianraschka.com>
 #
@@ -15,6 +15,9 @@ from .bootstrap_outofbag import BootstrapOutOfBag
 from .bootstrap_point632 import bootstrap_point632_score
 from .permutation import permutation_test
 from .cochrans_q import cochrans_q
+from .ttest import paired_ttest_resampled
+from .ttest import paired_ttest_kfold_cv
+from .ttest import paired_ttest_5x2cv
 
 
 __all__ = ["scoring", "confusion_matrix",
@@ -22,4 +25,5 @@ __all__ = ["scoring", "confusion_matrix",
            "mcnemar", "lift_score",
            "bootstrap", "permutation_test",
            "BootstrapOutOfBag", "bootstrap_point632_score",
-           "cochrans_q"]
+           "cochrans_q", "paired_ttest_resampled",
+           "paired_ttest_kfold_cv", "paired_ttest_5x2cv"]
