@@ -1,4 +1,4 @@
-# Sebastian Raschka 2014-2017
+# Sebastian Raschka 2014-2018
 # mlxtend Machine Learning Library Extensions
 # Author: Sebastian Raschka <sebastianraschka.com>
 #
@@ -12,8 +12,9 @@ from .dense_transformer import DenseTransformer
 from .copy_transformer import CopyTransformer
 from .onehot import one_hot
 from .onehot import OnehotTransactions
+from .transactionencoder import TransactionEncoder
 
 
 __all__ = ["MeanCenterer", "shuffle_arrays_unison", "CopyTransformer",
            "minmax_scaling", "standardize", "DenseTransformer",
-           "one_hot", "OnehotTransactions"]
+           "one_hot", "OnehotTransactions", "TransactionEncoder"]
