@@ -3,7 +3,7 @@
 # For explanation of approach, see:
 # dnc1994.com/2016/05/rank-10-percent-in-first-kaggle-competition-en/#Stacking
 #
-# Sebastian Raschka 2014-2017
+# Sebastian Raschka 2014-2018
 # mlxtend Machine Learning Library Extensions
 #
 # An ensemble-learning meta-regressor for out-of-fold stacking regression
@@ -17,6 +17,7 @@ from sklearn.base import BaseEstimator
 from sklearn.base import RegressorMixin
 from sklearn.base import TransformerMixin
 from sklearn.base import clone
+from sklearn.exceptions import NotFittedError
 from sklearn.model_selection._split import check_cv
 from ..externals import six
 from ..externals.name_estimators import _name_estimators
@@ -72,10 +73,17 @@ class StackingCVRegressor(BaseEstimator, RegressorMixin, TransformerMixin):
         meta-regressor stored in the `self.train_meta_features_` array,
         which can be
         accessed after calling `fit`.
+    refit : bool (default: True)
+        Clones the regressors for stacking regression if True (default)
+        or else uses the original ones, which will be refitted on the dataset
+        upon calling the `fit` method. Setting refit=False is
+        recommended if you are working with estimators that are supporting
+        the scikit-learn fit/predict API interface but are not compatible
+        to scikit-learn's `clone` function.
 
     Attributes
     ----------
-    train_meta_features : numpy array, shape = [n_samples, len(self.regressors)]
+    train_meta_features : numpy array, shape = [n_samples, n_regressors]
         meta-features for training data, where n_samples is the
         number of samples
         in training data and len(self.regressors) is the number of regressors.
@@ -84,7 +92,8 @@ class StackingCVRegressor(BaseEstimator, RegressorMixin, TransformerMixin):
     def __init__(self, regressors, meta_regressor, cv=5,
                  shuffle=True,
                  use_features_in_secondary=False,
-                 store_train_meta_features=False):
+                 store_train_meta_features=False,
+                 refit=True):
 
         self.regressors = regressors
         self.meta_regressor = meta_regressor
@@ -98,6 +107,7 @@ class StackingCVRegressor(BaseEstimator, RegressorMixin, TransformerMixin):
         self.shuffle = shuffle
         self.use_features_in_secondary = use_features_in_secondary
         self.store_train_meta_features = store_train_meta_features
+        self.refit = refit
 
     def fit(self, X, y, groups=None):
         """ Fit ensemble regressors and the meta-regressor.
@@ -120,8 +130,12 @@ class StackingCVRegressor(BaseEstimator, RegressorMixin, TransformerMixin):
         self : object
 
         """
-        self.regr_ = [clone(x) for x in self.regressors]
-        self.meta_regr_ = clone(self.meta_regressor)
+        if self.refit:
+            self.regr_ = [clone(clf) for clf in self.regressors]
+            self.meta_regr_ = clone(self.meta_regressor)
+        else:
+            self.clfs_ = self.regressors
+            self.meta_clf_ = self.meta_regressor
 
         kfold = check_cv(self.cv, y)
         if isinstance(self.cv, int):
@@ -188,6 +202,11 @@ class StackingCVRegressor(BaseEstimator, RegressorMixin, TransformerMixin):
         # First we make predictions with the base-models then we predict with
         # the meta-model from that info.
         #
+
+        if not hasattr(self, 'regr_'):
+            raise NotFittedError("Estimator not fitted, "
+                                 "call `fit` before exploiting the model.")
+
         meta_features = np.column_stack([
             regr.predict(X) for regr in self.regr_
         ])
@@ -214,6 +233,9 @@ class StackingCVRegressor(BaseEstimator, RegressorMixin, TransformerMixin):
             of regressors.
 
         """
+        if not hasattr(self, 'regr_'):
+            raise NotFittedError("Estimator not fitted, "
+                                 "call `fit` before exploiting the model.")
         return np.column_stack([regr.predict(X) for regr in self.regr_])
 
     def get_params(self, deep=True):
